@@ -160,6 +160,9 @@ typedef struct {
 
 	/* frames to use for thumbnail icons */
 	GdkPixbuf *thumbnail_frame;
+
+	/* Used for icon themes according to the freedesktop icon spec. */
+	GnomeIconLoader *icon_loader;
 } NautilusIconFactory;
 
 #define NAUTILUS_ICON_FACTORY(obj) \
@@ -314,6 +317,36 @@ nautilus_icon_factory_get (void)
 	return GTK_OBJECT (get_icon_factory ());
 }
 
+static void
+icon_loader_changed_callback (GnomeIconLoader *icon_loader,
+			      gpointer user_data)
+{
+	NautilusIconFactory *factory;
+
+	factory = user_data;
+
+	g_signal_emit (factory,
+		       signals[ICONS_CHANGED], 0);
+}
+
+GnomeIconLoader *
+nautilus_icon_factory_get_icon_loader (void)
+{
+	NautilusIconFactory *factory;
+
+	factory = get_icon_factory ();
+
+	if (factory->icon_loader == NULL) {
+		factory->icon_loader = gnome_icon_loader_new ();
+		g_signal_connect_object (factory->icon_loader,
+					 "changed",
+					 G_CALLBACK (icon_loader_changed_callback),
+					 factory, 0);
+	}
+
+	return g_object_ref (factory->icon_loader);
+}
+
 static void
 check_recently_used_list (void)
 {
@@ -718,8 +751,8 @@ is_theme_in_user_directory (const char *theme_name)
 	}
 	
 	user_directory = nautilus_get_user_directory ();
-	themes_directory = nautilus_make_path (user_directory, "themes");
-	this_theme_directory = nautilus_make_path (themes_directory, theme_name);
+	themes_directory = g_build_filename (user_directory, "themes", NULL);
+	this_theme_directory = g_build_filename (themes_directory, theme_name, NULL);
 	
 	result = g_file_test (this_theme_directory, G_FILE_TEST_EXISTS);
 	
@@ -1577,7 +1610,7 @@ load_icon_from_path (const char *path,
 	}
 	
 	/* if it's a thumbnail, frame it if necessary */
-	if (strstr (path, "/.thumbnails/") != NULL) {
+	if (strstr (path, "/.nautilus/thumbnails/") != NULL) {
 		return nautilus_thumbnail_load_framed_image (path);
 	}
 	
