@@ -1376,13 +1376,12 @@ fm_icon_view_update_menus (FMDirectoryView *view)
 				       && icon_container != NULL
 			    	       && !nautilus_icon_container_has_stretch_handles (icon_container));
 
-	nautilus_bonobo_set_label_for_menu_item_and_command 
+	nautilus_bonobo_set_label
 		(icon_view->details->ui,
-		 MENU_PATH_UNSTRETCH_ICONS,
 		 COMMAND_UNSTRETCH_ICONS,
 		 eel_g_list_more_than_one_item (selection)
-		 	? _("Restore Icons' _Original Sizes")
-		 	: _("Restore Icon's _Original Size"));
+		 	? _("Restore Icons' Original Si_zes")
+		 	: _("Restore Icon's Original Si_ze"));
 	nautilus_bonobo_set_sensitive (icon_view->details->ui, 
 				       COMMAND_UNSTRETCH_ICONS,
 				       icon_container != NULL
@@ -1945,7 +1944,7 @@ get_icon_drop_target_uri_callback (NautilusIconContainer *container,
 	/* Check for Nautilus link */
 	if (nautilus_file_is_nautilus_link (file)) {
 		/* FIXME bugzilla.gnome.org 43020: This does sync. I/O and works only locally. */
-		if (nautilus_file_is_local (file)) {
+		if (!eel_vfs_has_capability (uri, EEL_VFS_CAPABILITY_IS_REMOTE_AND_SLOW)) {
 			target_uri = nautilus_link_local_get_link_uri (uri);
 			if (target_uri != NULL) {
 				g_free (uri);
@@ -2232,13 +2231,12 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 
 	GList *uri_list;
 	GList *node, *real_uri_list = NULL;
-	GnomeVFSURI *container_uri;
 	GnomeDesktopItem *entry;
 	GdkPoint point;
 	char *uri;
 	char *path;
 	char *stripped_uri;
-	char *container_uri_string;
+	char *container_uri;
 	const char *last_slash, *link_name;
 	int n_uris;
 	gboolean all_local;
@@ -2248,16 +2246,15 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 		return;
 	}
 
-	container_uri_string = fm_directory_view_get_uri (FM_DIRECTORY_VIEW (view));
-	container_uri = gnome_vfs_uri_new (container_uri_string);
+	container_uri = fm_directory_view_get_uri (FM_DIRECTORY_VIEW (view));
 	g_return_if_fail (container_uri != NULL);
 
-	if (!gnome_vfs_uri_is_local (container_uri)) {
+	if (eel_vfs_has_capability (container_uri,
+				    EEL_VFS_CAPABILITY_IS_REMOTE_AND_SLOW)) {
 		eel_show_warning_dialog (_("Drag and drop is only supported to local file systems."),
 					 _("Drag and Drop error"),
 					 fm_directory_view_get_containing_window (FM_DIRECTORY_VIEW (view)));
-		gnome_vfs_uri_unref (container_uri);
-		g_free (container_uri_string);
+		g_free (container_uri);
 		return;
 	}
 
@@ -2275,8 +2272,7 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 		eel_show_warning_dialog (_("An invalid drag type was used."),
 					 _("Drag and Drop error"),
 					 fm_directory_view_get_containing_window (FM_DIRECTORY_VIEW (view)));
-		gnome_vfs_uri_unref (container_uri);
-		g_free (container_uri_string);
+		g_free (container_uri);
 		return;
 	}
 
@@ -2298,8 +2294,10 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 		if (sanitized_uri == NULL)
 			continue;
 		real_uri_list = g_list_append (real_uri_list, sanitized_uri);
-		if (strncmp (sanitized_uri, "file", 4) != 0)
+		if (eel_vfs_has_capability (sanitized_uri,
+					    EEL_VFS_CAPABILITY_IS_REMOTE_AND_SLOW)) {
 			all_local = FALSE;
+		}
 		n_uris++;
 	}
 	nautilus_icon_dnd_uri_list_free_strings (uri_list);
@@ -2318,7 +2316,7 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 			points = NULL;
 		}
 		fm_directory_view_move_copy_items (real_uri_list, points,
-						   container_uri_string,
+						   container_uri,
 						   action, x, y, FM_DIRECTORY_VIEW (view));
 		
 		if (points)
@@ -2340,7 +2338,7 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 
 			if (entry != NULL) {
 				/* FIXME: Handle name conflicts? */
-				nautilus_link_local_create_from_gnome_entry (entry, container_uri_string, &point);
+				nautilus_link_local_create_from_gnome_entry (entry, container_uri, &point);
 
 				gnome_desktop_item_unref (entry);
 				continue;
@@ -2358,7 +2356,7 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 			
 			if (!eel_str_is_empty (link_name)) {
 				/* FIXME: Handle name conflicts? */
-				nautilus_link_local_create (container_uri_string, link_name,
+				nautilus_link_local_create (container_uri, link_name,
 							    NULL, uri,
 							    &point, NAUTILUS_LINK_GENERIC);
 			}
@@ -2370,8 +2368,7 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 	
 	nautilus_icon_dnd_uri_list_free_strings (real_uri_list);
 
-	gnome_vfs_uri_unref (container_uri);
-	g_free (container_uri_string);
+	g_free (container_uri);
 	
 }
 
